==> de.uka.ipd.sdq.workflow.mdsd.source_2.1.0.201511050943.jar: de/uka/ipd/sdq/workflow/mdsd/AbstractMDSDWorkbenchDelegate.java <==
package de.uka.ipd.sdq.workflow.mdsd;

import org.eclipse.core.runtime.NullProgressMonitor;

import de.uka.ipd.sdq.workflow.BlackboardBasedWorkflow;
import de.uka.ipd.sdq.workflow.Workflow;
import de.uka.ipd.sdq.workflow.configuration.AbstractJobConfiguration;
import de.uka.ipd.sdq.workflow.mdsd.blackboard.MDSDBlackboard;
import de.uka.ipd.sdq.workflow.workbench.AbstractWorkbenchDelegate;

/**
 * The Class AbstractMDSDWorkbenchDelegate.
 * 
 * @param <WorkflowConfigurationType>
 *            the generic type
 * @param <WorkflowType>
 *            the generic type
 */
public abstract class AbstractMDSDWorkbenchDelegate<WorkflowConfigurationType extends AbstractJobConfiguration, WorkflowType extends Workflow>
        extends AbstractWorkbenchDelegate<WorkflowConfigurationType, WorkflowType> {

    /**
     * Instantiate the workflow engine. By default a standard workflow engine is created.
     * 
     * @param workflowConfiguration
     *            Configuration of the workflow job
     * @return The workflow engine to use for this launch
     */
    @SuppressWarnings("unchecked")
    protected WorkflowType createWorkflow(WorkflowConfigurationType workflowConfiguration) {
        return (WorkflowType) new BlackboardBasedWorkflow<MDSDBlackboard>(createWorkflowJob(workflowConfiguration),
                new NullProgressMonitor(),
                // createExceptionHandler(workflowConfiguration.isInteractive()));
                createExceptionHandler(true), new MDSDBlackboard());
    }

}

==> de.uka.ipd.sdq.workflow.mdsd.source_6.0.0.202602050039.jar: de/uka/ipd/sdq/workflow/mdsd/AbstractMDSDWorkbenchDelegate.java <==
package de.uka.ipd.sdq.workflow.mdsd;

import org.eclipse.core.runtime.NullProgressMonitor;

import de.uka.ipd.sdq.workflow.BlackboardBasedWorkflow;
import de.uka.ipd.sdq.workflow.Workflow;
import de.uka.ipd.sdq.workflow.configuration.AbstractJobConfiguration;
import de.uka.ipd.sdq.workflow.mdsd.blackboard.MDSDBlackboard;
import de.uka.ipd.sdq.workflow.workbench.AbstractWorkbenchDelegate;

/**
 * The Class AbstractMDSDWorkbenchDelegate.
 *
 * @param <WorkflowConfigurationType>
 *            the generic type
 * @param <WorkflowType>
 *            the generic type
 */
public abstract class AbstractMDSDWorkbenchDelegate<WorkflowConfigurationType extends AbstractJobConfiguration, WorkflowType extends Workflow>
        extends AbstractWorkbenchDelegate<WorkflowConfigurationType, WorkflowType> {

    /**
     * Instantiate the workflow engine. By default a standard workflow engine is created.
     *
     * @param workflowConfiguration
     *            Configuration of the workflow job
     * @return The workflow engine to use for this launch
     */
    @Override
    @SuppressWarnings("unchecked")
    protected WorkflowType createWorkflow(final WorkflowConfigurationType workflowConfiguration) {
        return (WorkflowType) new BlackboardBasedWorkflow<MDSDBlackboard>(this.createWorkflowJob(workflowConfiguration),
                new NullProgressMonitor(),
                // createExceptionHandler(workflowConfiguration.isInteractive()));
                this.createExceptionHandler(true), new MDSDBlackboard());
    }

}
